==> at_events_flutter-2.0.3.tar.gz: lib/services/contact_service.dart <==
import 'package:at_commons/at_commons.dart';
import 'package:at_contact/at_contact.dart';

import 'event_key_stream_service.dart';

Future<AtContact> getAtSignDetails(String? atSign) async {
  var atContact = getCachedContactDetail(atSign);
  if (atContact == null) {
    var contactDetails = await getContactDetails(atSign);
    atContact = AtContact(
      atSign: atSign,
      tags: contactDetails,
    );
  }
  return atContact;
}

AtContact? getCachedContactDetail(String? atsign) {
  if (atsign ==
      EventKeyStreamService().atContactImpl?.atClient?.currentAtSign) {
    return EventKeyStreamService().loggedInUserDetails;
  }
  if (EventKeyStreamService().contactList.isNotEmpty) {
    var index = EventKeyStreamService()
        .contactList
        .indexWhere((element) => element.atSign == atsign);
    if (index > -1) return EventKeyStreamService().contactList[index];
  }
  return null;
}

Future<Map<String, dynamic>> getContactDetails(atSign) async {
  var contactDetails = <String, dynamic>{};

  if (EventKeyStreamService().atClientInstance == null || atSign == null) {
    return contactDetails;
  } else if (!atSign.contains('@')) {
    atSign = '@' + atSign;
  }
  var metadata = Metadata();
  metadata.isPublic = true;
  metadata.namespaceAware = false;
  var key = AtKey();
  key.sharedBy = atSign;
  key.metadata = metadata;
  var contactFields = [
    'firstname.persona',
    'lastname.persona',
    'image.persona',
  ];

  try {
    // firstname
    key.key = contactFields[0];
    var result =
        await EventKeyStreamService().atClientInstance!.get(key).catchError(
            // ignore: return_of_invalid_type_from_catch_error
            (e) => print('error in get ${e.errorCode} ${e.errorMessage}'));
    var firstname = result.value;

    // lastname
    key.key = contactFields[1];
    result = await EventKeyStreamService().atClientInstance!.get(key);
    var lastname = result.value;

    // construct name
    var name = ((firstname ?? '') + ' ' + (lastname ?? '')).trim();
    if (name.length == 0) {
      name = atSign.substring(1);
    }

    // profile picture
    key.metadata!.isBinary = true;
    key.key = contactFields[2];
    result = await EventKeyStreamService().atClientInstance!.get(key);
    var image = result.value;
    contactDetails['name'] = name;
    contactDetails['image'] = image;
  } catch (e) {
    contactDetails['name'] = null;
    contactDetails['image'] = null;
  }
  return contactDetails;
}

==> at_events_flutter-3.0.2.tar.gz: lib/services/contact_service.dart <==
import 'package:at_commons/at_commons.dart';
import 'package:at_contact/at_contact.dart';

import 'event_key_stream_service.dart';

Future<AtContact> getAtSignDetails(String? atSign) async {
  var atContact = getCachedContactDetail(atSign);
  if (atContact == null) {
    var contactDetails = await getContactDetails(atSign);
    atContact = AtContact(
      atSign: atSign,
      tags: contactDetails,
    );
  }
  return atContact;
}

AtContact? getCachedContactDetail(String? atsign) {
  if (atsign ==
      EventKeyStreamService().atContactImpl?.atClient?.getCurrentAtSign()) {
    return EventKeyStreamService().loggedInUserDetails;
  }
  if (EventKeyStreamService().contactList.isNotEmpty) {
    var index = EventKeyStreamService()
        .contactList
        .indexWhere((element) => element.atSign == atsign);
    if (index > -1) return EventKeyStreamService().contactList[index];
  }
  return null;
}

Future<Map<String, dynamic>> getContactDetails(atSign) async {
  var contactDetails = <String, dynamic>{};

  if (EventKeyStreamService().atClientManager == null || atSign == null) {
    return contactDetails;
  } else if (!atSign.contains('@')) {
    atSign = '@' + atSign;
  }
  var metadata = Metadata();
  metadata.isPublic = true;
  metadata.namespaceAware = false;
  var key = AtKey();
  key.sharedBy = atSign;
  key.metadata = metadata;
  var contactFields = [
    'firstname.persona',
    'lastname.persona',
    'image.persona',
  ];

  try {
    // firstname
    key.key = contactFields[0];
    var result = await EventKeyStreamService()
        .atClientManager
        .atClient
        .get(key)
        .catchError(
            // ignore: return_of_invalid_type_from_catch_error
            (e) => print('error in get ${e.errorCode} ${e.errorMessage}'));
    var firstname = result.value;

    // lastname
    key.key = contactFields[1];
    result = await EventKeyStreamService().atClientManager.atClient.get(key);
    var lastname = result.value;

    // construct name
    var name = ((firstname ?? '') + ' ' + (lastname ?? '')).trim();
    if (name.length == 0) {
      name = atSign.substring(1);
    }

    // profile picture
    key.metadata!.isBinary = true;
    key.key = contactFields[2];
    result = await EventKeyStreamService().atClientManager.atClient.get(key);
    var image = result.value;
    contactDetails['name'] = name;
    contactDetails['image'] = image;
  } catch (e) {
    contactDetails['name'] = null;
    contactDetails['image'] = null;
  }
  return contactDetails;
}
